@@ -35,7 +35,7 @@ to_latex.huxtable <- function (ht, tabular_only = FALSE, ...){
 
   if (! is.na(height <- height(ht))) {
     if (is.numeric(height)) height <- paste0(height, '\\textheight')
-    res <- tex_glue('\\resizebox*{!}{<< height >>}{\n<< res >>\n}')
+    res <- paste0('\\resizebox*{!}{', height, '}{\n', res, '\n}')
   }
 
   cap <- if (! is.na(cap <- caption(ht))) {
@@ -46,9 +46,9 @@ to_latex.huxtable <- function (ht, tabular_only = FALSE, ...){
             center = 'centering',
             right  = 'raggedleft'
           )
-    tex_glue('\\captionsetup{justification=<< cap_setup >>,singlelinecheck=off}\n\\caption{<< cap >>}\n')
+    paste0('\\captionsetup{justification=', cap_setup, ',singlelinecheck=off}\n\\caption{', cap, '}\n')
   } else ''
-  lab <- if (! is.na(lab <- label(ht))) tex_glue('\\label{<< lab >>}\n') else ''
+  lab <- if (is.na(lab <- label(ht))) '' else paste0('\\label{', lab, '}\n')
   if (nzchar(lab) && ! nzchar(cap)) warning('No caption set: LaTeX table labels may not work as expected.')
   res <- if (grepl('top', caption_pos(ht))) paste0(cap, lab, res) else paste0(res, cap, lab)
 
@@ -60,7 +60,7 @@ to_latex.huxtable <- function (ht, tabular_only = FALSE, ...){
   )
   res <- paste0(pos_text[1], res, pos_text[2], '\n')
 
-  res <- tex_glue('\\begin{table}[<< latex_float(ht) >>]\n<< res >>\\end{table}\n')
+  res <- paste0('\\begin{table}[', latex_float(ht), ']\n', res, '\\end{table}\n')
 
   return(res)
 }
@@ -97,9 +97,9 @@ report_latex_dependencies <- function(quiet = FALSE, as_string = FALSE) {
     package_str <- '\\usepackage'
     if (! is.null(ld$options)) {
       options_str <- paste(ld$options, collapse = ',')
-      package_str <- tex_glue('<< package_str >>[<< options_str >>]')
+      package_str <- paste0(package_str, '[', options_str, ']')
     }
-    package_str <- tex_glue('<< package_str >>{<< ld$name >>}\n')
+    package_str <- paste0(package_str, '{', ld$name, '}\n')
     package_str
   })
   if (! quiet) {
@@ -112,13 +112,15 @@ report_latex_dependencies <- function(quiet = FALSE, as_string = FALSE) {
 
 
 build_tabular <- function(ht) {
-  colspec <- sapply(seq_len(ncol(ht)), function (mycol) tex_glue('p{<< compute_width(ht, mycol, mycol) >>}'))
+  colspec <- sapply(seq_len(ncol(ht)), function (mycol) paste0('p{', compute_width(ht, mycol, mycol), '}'))
   colspec <- paste0(colspec, collapse = ' ')
-  res <- tex_glue('{<< colspec >>}\n')
+  res <- paste0('{', colspec, '}\n')
 
-  display_cells <- display_cells(ht, all = TRUE)
-  all_contents  <- clean_contents(ht, type = 'latex')
-  res <- paste0(res, build_clines_for_row(ht, row = 0))
+  display_cells     <- display_cells(ht, all = TRUE)
+  all_contents      <- clean_contents(ht, type = 'latex')
+  collapsed_borders <- collapsed_borders(ht)
+  cb_colors         <- collapsed_border_colors(ht)
+  res <- paste0(res, build_clines_for_row(ht, row = 0, collapsed_borders, cb_colors))
 
   for (myrow in 1:nrow(ht)) {
     row_contents <- character(0)
@@ -144,8 +146,8 @@ build_tabular <- function(ht) {
         padding <- list(left_padding(ht)[drow, dcol], right_padding(ht)[drow, dcol], top_padding(ht)[drow, dcol],
               bottom_padding(ht)[drow, dcol])
         padding <- lapply(padding, function(x) if (is_a_number(x)) paste0(x, 'pt') else x)
-        tpadding <- if (is.na(padding[3])) '' else tex_glue('\\rule{0pt}{\\baselineskip+<< padding[3] >>}')
-        bpadding <- if (is.na(padding[4])) '' else tex_glue('\\rule[-<< padding[4] >>]{0pt}{<< padding[4] >>}')
+        tpadding <- if (is.na(padding[3])) '' else paste0('\\rule{0pt}{\\baselineskip+', padding[3], '}')
+        bpadding <- if (is.na(padding[4])) '' else paste0('\\rule[-', padding[4], ']{0pt}{', padding[4], '}')
         align_str <- switch(align(ht)[drow, dcol],
           left   = '\\raggedright ',
           right  = '\\raggedleft ',
@@ -158,17 +160,16 @@ build_tabular <- function(ht) {
           # reverse of what you think. 'b' aligns the *bottom* of the text with the baseline
           # this doesn't really work for short text!
           ctb <- switch(valign(ht)[drow, dcol], top = 'b', middle = 'c', bottom = 't')
-          contents   <- tex_glue(
-                '\\parbox[<< ctb >>]{<< width_spec >><< hpad_loss[1] >><< hpad_loss[2] >>}{<< contents >>}')
+          contents   <- paste0('\\parbox[', ctb, ']{', width_spec, hpad_loss[1], hpad_loss[2], '}{', contents, '}')
         }
-        hpadding <- lapply(padding[1:2], function (x) if (! is.na(x)) tex_glue('\\hspace*{<< x >>}') else '')
+        hpadding <- lapply(padding[1:2], function (x) if (is.na(x)) '' else paste0('\\hspace*{', x, '}'))
         contents <- paste0(hpadding[1], contents, hpadding[2])
 
         # to create row height, we add invisible \rule{0pt}. So, these heights are minimums.
         # not sure how this should interact with cell padding...
         if (! is.na(row_height <- row_height(ht)[drow])) {
-          if (is.numeric(row_height)) row_height <- tex_glue('<< row_height >>\\textheight')
-          contents <- tex_glue('<< contents >>\\rule{0pt}{<< row_height >>}')
+          if (is.numeric(row_height)) row_height <- paste0(row_height, '\\textheight')
+          contents <- paste0(contents, '\\rule{0pt}{', row_height, '}')
         }
       }
 
@@ -176,13 +177,13 @@ build_tabular <- function(ht) {
       # but only for left hand cells (which will be multicolumn{colspan} )
       if (! is.na(cell_color <- background_color(ht)[drow, dcol]) && mycol == dcol) {
         cell_color <- format_color(cell_color)
-        cell_color <- tex_glue('\\cellcolor[RGB]{<< cell_color >>}')
-        contents <- tex_glue('<< cell_color >> << contents >>')
+        cell_color <- paste0('\\cellcolor[RGB]{', cell_color, '}')
+        contents <- paste0(cell_color, ' ', contents)
       }
 
       if (bottom_left_multirow) {
         # * is 'standard width', could be more specific:
-        contents <- tex_glue('\\multirow{-<< rs >>}{*}{<< contents >>}')
+        contents <- paste0('\\multirow{-', rs, '}{*}{', contents, '}')
       }
 
       if (mycol == dcol) { # first column of cell
@@ -190,15 +191,15 @@ build_tabular <- function(ht) {
         colspec <- if (wrap(ht)[drow, dcol]) {
           pmb <- switch(valign(ht)[drow, dcol], top   = 'p', bottom  = 'b', middle = 'm')
           width_spec <- compute_width(ht, mycol, dcell$end_col)
-          tex_glue('<< pmb >>{<< width_spec >>}')
+          paste0(pmb, '{', width_spec, '}')
         } else {
           switch(align(ht)[drow, dcol], left = 'l', center = 'c', right = 'r')
         }
         # only add left borders if we haven't already added a right border!
-        lb <- if (! added_right_border) v_border(ht, myrow, mycol) else ''
-        rb <- v_border(ht, myrow, dcell$end_col + 1) # we need to put the end column here
+        lb <- if (! added_right_border) v_border(ht, myrow, mycol, collapsed_borders, cb_colors) else ''
+        rb <- v_border(ht, myrow, dcell$end_col + 1, collapsed_borders, cb_colors) # we need to put the end column here
         added_right_border <- rb != ''
-        contents <- tex_glue('\\multicolumn{<< cs >>}{<< lb >><< colspec >><< rb >>}{<< contents >>}')
+        contents <- paste0('\\multicolumn{', cs, '}{', lb, colspec, rb, '}{', contents, '}')
       }
 
       row_contents[mycol] <- contents
@@ -207,21 +208,21 @@ build_tabular <- function(ht) {
     row_contents <- row_contents[nzchar(row_contents)] # if we've printed nothing, don't print an & for it
     row_contents <- paste(row_contents, collapse = ' & \n')
     # should reduce nasty pale lines through colored multirow cells:
-    res <- tex_glue('<< res >><< row_contents >> \\tabularnewline[-0.5pt]\n')
+    res <- paste0(res, row_contents, '\\tabularnewline[-0.5pt]\n')
 
     # add top/bottom borders
-    res <- paste0(res, build_clines_for_row(ht, myrow))
+    res <- paste0(res, build_clines_for_row(ht, myrow, collapsed_borders, cb_colors))
   } # next row
 
   tenv <- tabular_environment(ht)
   width_spec <- if (tenv %in% c('tabularx', 'tabular*', 'tabulary')) {
     tw <- width(ht)
     if (is_a_number(tw)) tw <- paste0(tw, default_table_width_unit)
-    tex_glue('{<< tw >>}')
+    paste0('{', tw, '}')
   } else {
     ''
   }
-  res <- tex_glue('\\begin{<< tenv >>}<< width_spec >><< res >>\\end{<< tenv >>}\n')
+  res <- paste0('\\begin{',  tenv, '}', width_spec, res, '\\end{', tenv, '}\n')
 
   return(res)
 }
@@ -253,7 +254,7 @@ compute_width <- function (ht, start_col, end_col) {
   if (end_col > start_col) {
     # need to add some extra tabcolseps, two per column
     extra_seps <- (end_col - start_col) * 2
-    cw <- tex_glue('<< cw >>+<< extra_seps >>\\tabcolsep')
+    cw <- paste0(cw, '+', extra_seps, '\\tabcolsep')
   }
 
   cw
@@ -262,56 +263,54 @@ compute_width <- function (ht, start_col, end_col) {
 build_cell_contents <- function(ht, row, col, contents) {
   if (! is.na(font_size <- font_size(ht)[row, col])) {
     line_space <- round(font_size * 1.2, 2)
-    contents <- tex_glue('{\\fontsize{<< font_size >>pt}{<< line_space >>pt}\\selectfont << contents >>}')
+    contents <- paste0('{\\fontsize{', font_size, 'pt}{', line_space, 'pt}\\selectfont ', contents, '}')
   }
   if (! is.na(text_color <- text_color(ht)[row, col])) {
     text_color <- format_color(text_color)
-    contents <- tex_glue('\\textcolor[RGB]{<< text_color >>}{<< contents >>}')
+    contents <- paste0('\\textcolor[RGB]{', text_color, '}{', contents, '}')
   }
-  if (bold(ht)[row, col])   contents <- tex_glue('\\textbf{<< contents >>}')
-  if (italic(ht)[row, col]) contents <- tex_glue('\\textit{<< contents >>}')
+  if (bold(ht)[row, col])   contents <- paste0('\\textbf{', contents, '}')
+  if (italic(ht)[row, col]) contents <- paste0('\\textit{', contents, '}')
   if (! is.na(font <- font(ht)[row, col])) {
-    contents <- tex_glue('{\\fontfamily{<< font >>}\\selectfont << contents >>}')
+    contents <- paste0('{\\fontfamily{', font, '}\\selectfont ', contents, '}')
   }
-  if ( (rt <- rotation(ht)[row, col]) != 0) contents <- tex_glue('\\rotatebox{<< rt >>}{<< contents >>}')
+  if ( (rt <- rotation(ht)[row, col]) != 0) contents <- paste0('\\rotatebox{', rt, '}{', contents, '}')
 
   return(contents)
 }
 
 # row can be from "0" for the top; up to nrow
-build_clines_for_row <- function(ht, row) {
+build_clines_for_row <- function(ht, row, collapsed_borders, cb_colors) {
   # where a cell is shadowed, we don't want to add a top border (it'll go thru the middle)
   # bottom borders of a shadowed cell are fine, but come from the display cell.
   display_cells <- display_cells(ht, all = TRUE)
   display_cells <- display_cells[display_cells$row == row, ]
 
-  blank_line_color <- rep(NA, ncol(ht)) # white by default, I guess...
+  blank_line_color <- rep('white', ncol(ht)) # never now used
   for (i in seq_len(nrow(display_cells))) {
     dc <- display_cells[i, ]
-    # Use color if we are in middle of display cell
-    if (row < dc$end_row) {
-      col <- background_color(ht)[dc$display_row, dc$display_col]
-      blank_line_color[dc$display_col:dc$end_col] <- format_color(col, default = 'white')
-    }
+    # Use color if we are in middle of display cell, also if we are at end and after a +ve border
+      blank_line_color[dc$display_col:dc$end_col] <- background_color(ht)[dc$display_row, dc$display_col]
   }
 
-  widths <- collapsed_borders(ht)$horiz[row + 1,]
+  widths <- collapsed_borders$horiz[row + 1,]
   if (all(widths == 0)) {
     return('')
   } else {
     width <- max(widths)
     if (! all(widths[widths > 0] == width)) warning("Multiple widths in a single border, using max")
-    colors <- collapsed_border_colors(ht)$horiz[row + 1, ]
+    colors <- cb_colors$horiz[row + 1, ]
     colors <- sapply(colors, format_color, default = 'black')
+    blank_line_color <- sapply(blank_line_color, format_color, default = 'white')
     hhlinechars <- sapply(seq_along(widths), function (x) {
       col <- if (widths[x] > 0) colors[x] else blank_line_color[x]
-      tex_glue('>{\\arrayrulecolor[RGB]{<< col >>}\\global\\arrayrulewidth=<< width >>pt}-')
+      paste0('>{\\arrayrulecolor[RGB]{', col, '}\\global\\arrayrulewidth=', width, 'pt}-')
     })
-    vertlines <- compute_vertical_borders(ht, row)
+    vertlines <- compute_vertical_borders(ht, row, collapsed_borders, cb_colors)
 
     hhline <- paste0(hhlinechars, vertlines[-1], collapse = '')
     hhline <- paste0(vertlines[1], hhline)
-    hhline <- tex_glue('\n\n\\hhline{<< hhline >>}\n\\arrayrulecolor{black}\n')
+    hhline <- paste0('\n\n\\hhline{', hhline, '}\n\\arrayrulecolor{black}\n')
     return(hhline)
   }
 }
@@ -322,29 +321,26 @@ build_clines_for_row <- function(ht, row) {
 # left of above_right, right of below_left, left of below_right).
 # row can be 0 for the top line.
 # returns an ncol(ht) + 1 string array
-compute_vertical_borders <- function (ht, row) {
+compute_vertical_borders <- function (ht, row, collapsed_borders, cb_colors) {
   # if we are at the top line, then we'll assume we want the same vertical borders as on the first line below.
   if (row == 0) row <- 1
-  b_widths <- collapsed_borders(ht)$vert[row, ]
-  b_cols   <- collapsed_border_colors(ht)$vert[row, ]
+  b_widths <- collapsed_borders$vert[row, ]
+  b_cols   <- cb_colors$vert[row, ]
   borders <- sapply(seq_along(b_widths), function (x){
     if (b_widths[x] == 0 ) return('')
     my_col <- format_color(b_cols[x], default = 'black')
-    tex_glue('>{\\arrayrulecolor[RGB]{<< my_col >>}\\global\\arrayrulewidth=<< b_widths[x] >>pt}|')
+    paste0('>{\\arrayrulecolor[RGB]{', my_col, '}\\global\\arrayrulewidth=', b_widths[x], 'pt}|')
   })
 
   return(borders)
 }
 
 # uses "real" border numbers in "ncol + 1 space"
-v_border <- function (ht, row, col) {
-  width <- collapsed_borders(ht)$vert[row, col]
-  color <- collapsed_border_colors(ht)$vert[row, col]
+v_border <- function (ht, row, col, collapsed_borders, cb_colors) {
+  width <- collapsed_borders$vert[row, col]
+  color <- cb_colors$vert[row, col]
   color <- format_color(color, default = 'black')
 
-  tex_glue('!{\\color[RGB]{<< color >>}\\vrule width << width >>pt}')
+  paste0('!{\\color[RGB]{', color ,'}\\vrule width ', width, 'pt}')
 }
 
-
-# this has to have the ... argument as it's (???) evaluated in the parent frame
-tex_glue <- function (...) glue::glue(..., .open = '<<', .close = '>>', .envir = parent.frame())
